/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 29 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplayer.sip"
#include <qmediaplayer.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplayer.sip"
#include <qmediaplayer.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudio.sip"
#include <qaudio.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 344 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qaudio.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkconfiguration.sip"
#include <qnetworkconfiguration.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediacontent.sip"
#include <qmediacontent.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplaylist.sip"
#include <qmediaplaylist.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideosurface.sip"
#include <qabstractvideosurface.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaservice.sip"
#include <qmediaservice.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"


class sipQMediaPlayer : public ::QMediaPlayer
{
public:
    sipQMediaPlayer(::QObject*, ::QMediaPlayer::Flags);
    virtual ~sipQMediaPlayer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool isAvailable() const SIP_OVERRIDE;
    ::QMultimedia::AvailabilityStatus availability() const SIP_OVERRIDE;
    ::QMediaService* service() const SIP_OVERRIDE;
    bool bind(::QObject*) SIP_OVERRIDE;
    void unbind(::QObject*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaPlayer(const sipQMediaPlayer &);
    sipQMediaPlayer &operator = (const sipQMediaPlayer &);

    char sipPyMethods[12];
};

sipQMediaPlayer::sipQMediaPlayer(::QObject*a0, ::QMediaPlayer::Flags a1): ::QMediaPlayer(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaPlayer::~sipQMediaPlayer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaPlayer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaPlayer);

    return ::QMediaPlayer::metaObject();
}

int sipQMediaPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaPlayer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaPlayer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaPlayer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaPlayer, _clname, &sipCpp) ? sipCpp : ::QMediaPlayer::qt_metacast(_clname));
}

void sipQMediaPlayer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaPlayer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaPlayer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaPlayer::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaPlayer::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaPlayer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaPlayer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaPlayer::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQMediaPlayer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaPlayer::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaPlayer::isAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isAvailable);

    if (!sipMeth)
        return ::QMediaPlayer::isAvailable();

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMultimedia::AvailabilityStatus sipQMediaPlayer::availability() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_availability);

    if (!sipMeth)
        return ::QMediaPlayer::availability();

    extern ::QMultimedia::AvailabilityStatus sipVH_QtMultimedia_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_17(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaService* sipQMediaPlayer::service() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_service);

    if (!sipMeth)
        return ::QMediaPlayer::service();

    extern ::QMediaService* sipVH_QtMultimedia_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_18(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaPlayer::bind(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_bind);

    if (!sipMeth)
        return ::QMediaPlayer::bind(a0);

    extern bool sipVH_QtMultimedia_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    return sipVH_QtMultimedia_19(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::unbind(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_unbind);

    if (!sipMeth)
    {
        ::QMediaPlayer::unbind(a0);
        return;
    }

    extern void sipVH_QtMultimedia_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    sipVH_QtMultimedia_20(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaPlayer_hasSupport, "hasSupport(mimeType: Optional[str], codecs: Iterable[Optional[str]] = [], flags: Union[QMediaPlayer.Flags, QMediaPlayer.Flag] = QMediaPlayer.Flags()) -> QMultimedia.SupportEstimate");

extern "C" {static PyObject *meth_QMediaPlayer_hasSupport(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_hasSupport(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QStringList& a1def = QStringList();
        const ::QStringList* a1 = &a1def;
        int a1State = 0;
        ::QMediaPlayer::Flags a2def = QMediaPlayer::Flags();
        ::QMediaPlayer::Flags* a2 = &a2def;
        int a2State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_codecs,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J1|J1J1", sipType_QString, &a0, &a0State, sipType_QStringList, &a1, &a1State, sipType_QMediaPlayer_Flags, &a2, &a2State))
        {
            ::QMultimedia::SupportEstimate sipRes;

            sipRes = ::QMediaPlayer::hasSupport(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a1), sipType_QStringList, a1State);
            sipReleaseType(a2, sipType_QMediaPlayer_Flags, a2State);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_SupportEstimate);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_hasSupport, doc_QMediaPlayer_hasSupport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_supportedMimeTypes, "supportedMimeTypes(flags: Union[QMediaPlayer.Flags, QMediaPlayer.Flag] = QMediaPlayer.Flags()) -> list[str]");

extern "C" {static PyObject *meth_QMediaPlayer_supportedMimeTypes(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_supportedMimeTypes(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer::Flags a0def = QMediaPlayer::Flags();
        ::QMediaPlayer::Flags* a0 = &a0def;
        int a0State = 0;

        static const char *sipKwdList[] = {
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "|J1", sipType_QMediaPlayer_Flags, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QMediaPlayer::supportedMimeTypes(*a0));
            sipReleaseType(a0, sipType_QMediaPlayer_Flags, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_supportedMimeTypes, doc_QMediaPlayer_supportedMimeTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setVideoOutput, "setVideoOutput(self, a0: Optional[QVideoWidget])\n"
"setVideoOutput(self, a0: Optional[QGraphicsVideoItem])\n"
"setVideoOutput(self, surface: Optional[QAbstractVideoSurface])\n"
"setVideoOutput(self, surfaces: Iterable[QAbstractVideoSurface])");

extern "C" {static PyObject *meth_QMediaPlayer_setVideoOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setVideoOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVideoWidget* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QVideoWidget, &a0))
        {
            sipCpp->setVideoOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QGraphicsVideoItem* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QGraphicsVideoItem, &a0))
        {
            sipCpp->setVideoOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAbstractVideoSurface* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QAbstractVideoSurface, &a0))
        {
            sipCpp->setVideoOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const QVector< ::QAbstractVideoSurface*>* a0;
        int a0State = 0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QVector_0101QAbstractVideoSurface, &a0, &a0State))
        {
            sipCpp->setVideoOutput(*a0);
            sipReleaseType(const_cast<QVector< ::QAbstractVideoSurface*> *>(a0), sipType_QVector_0101QAbstractVideoSurface, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setVideoOutput, doc_QMediaPlayer_setVideoOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_media, "media(self) -> QMediaContent");

extern "C" {static PyObject *meth_QMediaPlayer_media(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_media(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaContent*sipRes;

            sipRes = new ::QMediaContent(sipCpp->media());

            return sipConvertFromNewType(sipRes, sipType_QMediaContent, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_media, doc_QMediaPlayer_media);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_mediaStream, "mediaStream(self) -> Optional[QIODevice]");

extern "C" {static PyObject *meth_QMediaPlayer_mediaStream(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_mediaStream(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            const ::QIODevice*sipRes;

            sipRes = sipCpp->mediaStream();

            return sipConvertFromType(const_cast< ::QIODevice *>(sipRes), sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_mediaStream, doc_QMediaPlayer_mediaStream);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_playlist, "playlist(self) -> Optional[QMediaPlaylist]");

extern "C" {static PyObject *meth_QMediaPlayer_playlist(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_playlist(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlaylist*sipRes;

            sipRes = sipCpp->playlist();

            return sipConvertFromType(sipRes, sipType_QMediaPlaylist, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_playlist, doc_QMediaPlayer_playlist);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_currentMedia, "currentMedia(self) -> QMediaContent");

extern "C" {static PyObject *meth_QMediaPlayer_currentMedia(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_currentMedia(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaContent*sipRes;

            sipRes = new ::QMediaContent(sipCpp->currentMedia());

            return sipConvertFromNewType(sipRes, sipType_QMediaContent, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_currentMedia, doc_QMediaPlayer_currentMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_state, "state(self) -> QMediaPlayer.State");

extern "C" {static PyObject *meth_QMediaPlayer_state(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlayer::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_state, doc_QMediaPlayer_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_mediaStatus, "mediaStatus(self) -> QMediaPlayer.MediaStatus");

extern "C" {static PyObject *meth_QMediaPlayer_mediaStatus(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_mediaStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlayer::MediaStatus sipRes;

            sipRes = sipCpp->mediaStatus();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_MediaStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_mediaStatus, doc_QMediaPlayer_mediaStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_duration(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_duration, doc_QMediaPlayer_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_position, "position(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_position(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->position();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_position, doc_QMediaPlayer_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_volume, "volume(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_volume(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->volume();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_volume, doc_QMediaPlayer_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_isMuted, "isMuted(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_isMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_isMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMuted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_isMuted, doc_QMediaPlayer_isMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_isAudioAvailable, "isAudioAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_isAudioAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_isAudioAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAudioAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_isAudioAvailable, doc_QMediaPlayer_isAudioAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_isVideoAvailable, "isVideoAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_isVideoAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_isVideoAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVideoAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_isVideoAvailable, doc_QMediaPlayer_isVideoAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_bufferStatus, "bufferStatus(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_bufferStatus(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_bufferStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->bufferStatus();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_bufferStatus, doc_QMediaPlayer_bufferStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_isSeekable, "isSeekable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_isSeekable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_isSeekable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSeekable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_isSeekable, doc_QMediaPlayer_isSeekable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_playbackRate, "playbackRate(self) -> float");

extern "C" {static PyObject *meth_QMediaPlayer_playbackRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_playbackRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->playbackRate();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_playbackRate, doc_QMediaPlayer_playbackRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_error, "error(self) -> QMediaPlayer.Error");

extern "C" {static PyObject *meth_QMediaPlayer_error(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlayer::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_error, doc_QMediaPlayer_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QMediaPlayer_errorString(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_errorString, doc_QMediaPlayer_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_currentNetworkConfiguration, "currentNetworkConfiguration(self) -> QNetworkConfiguration");

extern "C" {static PyObject *meth_QMediaPlayer_currentNetworkConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_currentNetworkConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QNetworkConfiguration*sipRes;

            sipRes = new ::QNetworkConfiguration(sipCpp->currentNetworkConfiguration());

            return sipConvertFromNewType(sipRes, sipType_QNetworkConfiguration, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_currentNetworkConfiguration, doc_QMediaPlayer_currentNetworkConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_availability, "availability(self) -> QMultimedia.AvailabilityStatus");

extern "C" {static PyObject *meth_QMediaPlayer_availability(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_availability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMultimedia::AvailabilityStatus sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QMediaPlayer::availability() : sipCpp->availability());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_AvailabilityStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_availability, doc_QMediaPlayer_availability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_play, "play(self)");

extern "C" {static PyObject *meth_QMediaPlayer_play(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_play(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            sipCpp->play();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_play, doc_QMediaPlayer_play);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_pause, "pause(self)");

extern "C" {static PyObject *meth_QMediaPlayer_pause(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_pause, doc_QMediaPlayer_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_stop, "stop(self)");

extern "C" {static PyObject *meth_QMediaPlayer_stop(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_stop, doc_QMediaPlayer_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setPosition, "setPosition(self, position: int)");

extern "C" {static PyObject *meth_QMediaPlayer_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setPosition, doc_QMediaPlayer_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setVolume, "setVolume(self, volume: int)");

extern "C" {static PyObject *meth_QMediaPlayer_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setVolume, doc_QMediaPlayer_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setMuted, "setMuted(self, muted: bool)");

extern "C" {static PyObject *meth_QMediaPlayer_setMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setMuted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setMuted, doc_QMediaPlayer_setMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setPlaybackRate, "setPlaybackRate(self, rate: float)");

extern "C" {static PyObject *meth_QMediaPlayer_setPlaybackRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setPlaybackRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setPlaybackRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setPlaybackRate, doc_QMediaPlayer_setPlaybackRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setMedia, "setMedia(self, media: QMediaContent, stream: Optional[QIODevice] = None)");

extern "C" {static PyObject *meth_QMediaPlayer_setMedia(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setMedia(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaContent* a0;
        ::QIODevice* a1 = 0;
        ::QMediaPlayer *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_stream,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QMediaContent, &a0, sipType_QIODevice, &a1))
        {
            sipCpp->setMedia(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setMedia, doc_QMediaPlayer_setMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setPlaylist, "setPlaylist(self, playlist: Optional[QMediaPlaylist])");

extern "C" {static PyObject *meth_QMediaPlayer_setPlaylist(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setPlaylist(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlaylist* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QMediaPlaylist, &a0))
        {
            sipCpp->setPlaylist(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setPlaylist, doc_QMediaPlayer_setPlaylist);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setNetworkConfigurations, "setNetworkConfigurations(self, configurations: Iterable[QNetworkConfiguration])");

extern "C" {static PyObject *meth_QMediaPlayer_setNetworkConfigurations(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setNetworkConfigurations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QNetworkConfiguration>* a0;
        int a0State = 0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QList_0100QNetworkConfiguration, &a0, &a0State))
        {
            sipCpp->setNetworkConfigurations(*a0);
            sipReleaseType(const_cast<QList< ::QNetworkConfiguration> *>(a0), sipType_QList_0100QNetworkConfiguration, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setNetworkConfigurations, doc_QMediaPlayer_setNetworkConfigurations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_bind, "bind(self, a0: Optional[QObject]) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_bind(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_bind(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QObject, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QMediaPlayer::bind(a0) : sipCpp->bind(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_bind, doc_QMediaPlayer_bind);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_unbind, "unbind(self, a0: Optional[QObject])");

extern "C" {static PyObject *meth_QMediaPlayer_unbind(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_unbind(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QObject, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QMediaPlayer::unbind(a0) : sipCpp->unbind(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_unbind, doc_QMediaPlayer_unbind);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_audioRole, "audioRole(self) -> QAudio.Role");

extern "C" {static PyObject *meth_QMediaPlayer_audioRole(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_audioRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QAudio::Role sipRes;

            sipRes = sipCpp->audioRole();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudio_Role);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_audioRole, doc_QMediaPlayer_audioRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setAudioRole, "setAudioRole(self, audioRole: QAudio.Role)");

extern "C" {static PyObject *meth_QMediaPlayer_setAudioRole(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setAudioRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudio::Role a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QAudio_Role, &a0))
        {
            sipCpp->setAudioRole(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setAudioRole, doc_QMediaPlayer_setAudioRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_supportedAudioRoles, "supportedAudioRoles(self) -> list[QAudio.Role]");

extern "C" {static PyObject *meth_QMediaPlayer_supportedAudioRoles(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_supportedAudioRoles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QList< ::QAudio::Role>*sipRes;

            sipRes = new ::QList< ::QAudio::Role>(sipCpp->supportedAudioRoles());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QAudio_Role, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_supportedAudioRoles, doc_QMediaPlayer_supportedAudioRoles);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_customAudioRole, "customAudioRole(self) -> str");

extern "C" {static PyObject *meth_QMediaPlayer_customAudioRole(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_customAudioRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->customAudioRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_customAudioRole, doc_QMediaPlayer_customAudioRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setCustomAudioRole, "setCustomAudioRole(self, audioRole: Optional[str])");

extern "C" {static PyObject *meth_QMediaPlayer_setCustomAudioRole(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setCustomAudioRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCustomAudioRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setCustomAudioRole, doc_QMediaPlayer_setCustomAudioRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_supportedCustomAudioRoles, "supportedCustomAudioRoles(self) -> list[str]");

extern "C" {static PyObject *meth_QMediaPlayer_supportedCustomAudioRoles(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_supportedCustomAudioRoles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->supportedCustomAudioRoles());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_supportedCustomAudioRoles, doc_QMediaPlayer_supportedCustomAudioRoles);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaPlayer(void *, const sipTypeDef *);}
static void *cast_QMediaPlayer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaPlayer *sipCpp = reinterpret_cast< ::QMediaPlayer *>(sipCppV);

    if (targetType == sipType_QMediaPlayer)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaObject)->ctd_cast(static_cast< ::QMediaObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaPlayer(void *, int);}
static void release_QMediaPlayer(void *sipCppV, int)
{
    ::QMediaPlayer *sipCpp = reinterpret_cast< ::QMediaPlayer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QMediaPlayer(Py_ssize_t);}
static void *array_QMediaPlayer(Py_ssize_t sipNrElem)
{
    return new ::QMediaPlayer[sipNrElem];
}


extern "C" {static void array_delete_QMediaPlayer(void *);}
static void array_delete_QMediaPlayer(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMediaPlayer *>(sipCpp);
}


extern "C" {static void dealloc_QMediaPlayer(sipSimpleWrapper *);}
static void dealloc_QMediaPlayer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaPlayer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaPlayer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaPlayer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaPlayer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaPlayer *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;
        ::QMediaPlayer::Flags a1def = QMediaPlayer::Flags();
        ::QMediaPlayer::Flags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ1", sipType_QObject, &a0, sipOwner, sipType_QMediaPlayer_Flags, &a1, &a1State))
        {
            sipCpp = new sipQMediaPlayer(a0, *a1);
            sipReleaseType(a1, sipType_QMediaPlayer_Flags, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaPlayer[] = {{108, 255, 1}};


static PyMethodDef methods_QMediaPlayer[] = {
    {sipName_audioRole, meth_QMediaPlayer_audioRole, METH_VARARGS, doc_QMediaPlayer_audioRole},
    {sipName_availability, meth_QMediaPlayer_availability, METH_VARARGS, doc_QMediaPlayer_availability},
    {sipName_bind, meth_QMediaPlayer_bind, METH_VARARGS, doc_QMediaPlayer_bind},
    {sipName_bufferStatus, meth_QMediaPlayer_bufferStatus, METH_VARARGS, doc_QMediaPlayer_bufferStatus},
    {sipName_currentMedia, meth_QMediaPlayer_currentMedia, METH_VARARGS, doc_QMediaPlayer_currentMedia},
    {sipName_currentNetworkConfiguration, meth_QMediaPlayer_currentNetworkConfiguration, METH_VARARGS, doc_QMediaPlayer_currentNetworkConfiguration},
    {sipName_customAudioRole, meth_QMediaPlayer_customAudioRole, METH_VARARGS, doc_QMediaPlayer_customAudioRole},
    {sipName_duration, meth_QMediaPlayer_duration, METH_VARARGS, doc_QMediaPlayer_duration},
    {sipName_error, meth_QMediaPlayer_error, METH_VARARGS, doc_QMediaPlayer_error},
    {sipName_errorString, meth_QMediaPlayer_errorString, METH_VARARGS, doc_QMediaPlayer_errorString},
    {sipName_hasSupport, SIP_MLMETH_CAST(meth_QMediaPlayer_hasSupport), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlayer_hasSupport},
    {sipName_isAudioAvailable, meth_QMediaPlayer_isAudioAvailable, METH_VARARGS, doc_QMediaPlayer_isAudioAvailable},
    {sipName_isMuted, meth_QMediaPlayer_isMuted, METH_VARARGS, doc_QMediaPlayer_isMuted},
    {sipName_isSeekable, meth_QMediaPlayer_isSeekable, METH_VARARGS, doc_QMediaPlayer_isSeekable},
    {sipName_isVideoAvailable, meth_QMediaPlayer_isVideoAvailable, METH_VARARGS, doc_QMediaPlayer_isVideoAvailable},
    {sipName_media, meth_QMediaPlayer_media, METH_VARARGS, doc_QMediaPlayer_media},
    {sipName_mediaStatus, meth_QMediaPlayer_mediaStatus, METH_VARARGS, doc_QMediaPlayer_mediaStatus},
    {sipName_mediaStream, meth_QMediaPlayer_mediaStream, METH_VARARGS, doc_QMediaPlayer_mediaStream},
    {sipName_pause, meth_QMediaPlayer_pause, METH_VARARGS, doc_QMediaPlayer_pause},
    {sipName_play, meth_QMediaPlayer_play, METH_VARARGS, doc_QMediaPlayer_play},
    {sipName_playbackRate, meth_QMediaPlayer_playbackRate, METH_VARARGS, doc_QMediaPlayer_playbackRate},
    {sipName_playlist, meth_QMediaPlayer_playlist, METH_VARARGS, doc_QMediaPlayer_playlist},
    {sipName_position, meth_QMediaPlayer_position, METH_VARARGS, doc_QMediaPlayer_position},
    {sipName_setAudioRole, meth_QMediaPlayer_setAudioRole, METH_VARARGS, doc_QMediaPlayer_setAudioRole},
    {sipName_setCustomAudioRole, meth_QMediaPlayer_setCustomAudioRole, METH_VARARGS, doc_QMediaPlayer_setCustomAudioRole},
    {sipName_setMedia, SIP_MLMETH_CAST(meth_QMediaPlayer_setMedia), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlayer_setMedia},
    {sipName_setMuted, meth_QMediaPlayer_setMuted, METH_VARARGS, doc_QMediaPlayer_setMuted},
    {sipName_setNetworkConfigurations, meth_QMediaPlayer_setNetworkConfigurations, METH_VARARGS, doc_QMediaPlayer_setNetworkConfigurations},
    {sipName_setPlaybackRate, meth_QMediaPlayer_setPlaybackRate, METH_VARARGS, doc_QMediaPlayer_setPlaybackRate},
    {sipName_setPlaylist, meth_QMediaPlayer_setPlaylist, METH_VARARGS, doc_QMediaPlayer_setPlaylist},
    {sipName_setPosition, meth_QMediaPlayer_setPosition, METH_VARARGS, doc_QMediaPlayer_setPosition},
    {sipName_setVideoOutput, meth_QMediaPlayer_setVideoOutput, METH_VARARGS, doc_QMediaPlayer_setVideoOutput},
    {sipName_setVolume, meth_QMediaPlayer_setVolume, METH_VARARGS, doc_QMediaPlayer_setVolume},
    {sipName_state, meth_QMediaPlayer_state, METH_VARARGS, doc_QMediaPlayer_state},
    {sipName_stop, meth_QMediaPlayer_stop, METH_VARARGS, doc_QMediaPlayer_stop},
    {sipName_supportedAudioRoles, meth_QMediaPlayer_supportedAudioRoles, METH_VARARGS, doc_QMediaPlayer_supportedAudioRoles},
    {sipName_supportedCustomAudioRoles, meth_QMediaPlayer_supportedCustomAudioRoles, METH_VARARGS, doc_QMediaPlayer_supportedCustomAudioRoles},
    {sipName_supportedMimeTypes, SIP_MLMETH_CAST(meth_QMediaPlayer_supportedMimeTypes), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlayer_supportedMimeTypes},
    {sipName_unbind, meth_QMediaPlayer_unbind, METH_VARARGS, doc_QMediaPlayer_unbind},
    {sipName_volume, meth_QMediaPlayer_volume, METH_VARARGS, doc_QMediaPlayer_volume}
};

static sipEnumMemberDef enummembers_QMediaPlayer[] = {
    {sipName_AccessDeniedError, static_cast<int>(::QMediaPlayer::AccessDeniedError), 110},
    {sipName_BufferedMedia, static_cast<int>(::QMediaPlayer::BufferedMedia), 113},
    {sipName_BufferingMedia, static_cast<int>(::QMediaPlayer::BufferingMedia), 113},
    {sipName_EndOfMedia, static_cast<int>(::QMediaPlayer::EndOfMedia), 113},
    {sipName_FormatError, static_cast<int>(::QMediaPlayer::FormatError), 110},
    {sipName_InvalidMedia, static_cast<int>(::QMediaPlayer::InvalidMedia), 113},
    {sipName_LoadedMedia, static_cast<int>(::QMediaPlayer::LoadedMedia), 113},
    {sipName_LoadingMedia, static_cast<int>(::QMediaPlayer::LoadingMedia), 113},
    {sipName_LowLatency, static_cast<int>(::QMediaPlayer::LowLatency), 111},
    {sipName_NetworkError, static_cast<int>(::QMediaPlayer::NetworkError), 110},
    {sipName_NoError, static_cast<int>(::QMediaPlayer::NoError), 110},
    {sipName_NoMedia, static_cast<int>(::QMediaPlayer::NoMedia), 113},
    {sipName_PausedState, static_cast<int>(::QMediaPlayer::PausedState), 114},
    {sipName_PlayingState, static_cast<int>(::QMediaPlayer::PlayingState), 114},
    {sipName_ResourceError, static_cast<int>(::QMediaPlayer::ResourceError), 110},
    {sipName_ServiceMissingError, static_cast<int>(::QMediaPlayer::ServiceMissingError), 110},
    {sipName_StalledMedia, static_cast<int>(::QMediaPlayer::StalledMedia), 113},
    {sipName_StoppedState, static_cast<int>(::QMediaPlayer::StoppedState), 114},
    {sipName_StreamPlayback, static_cast<int>(::QMediaPlayer::StreamPlayback), 111},
    {sipName_UnknownMediaStatus, static_cast<int>(::QMediaPlayer::UnknownMediaStatus), 113},
    {sipName_VideoSurface, static_cast<int>(::QMediaPlayer::VideoSurface), 111},
};

PyDoc_STRVAR(doc_QMediaPlayer, "\1QMediaPlayer(parent: Optional[QObject] = None, flags: Union[QMediaPlayer.Flags, QMediaPlayer.Flag] = QMediaPlayer.Flags())");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QMediaPlayer[] = {
    {"customAudioRoleChanged(QString)", "\1customAudioRoleChanged(self, role: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"audioRoleChanged(QAudio::Role)", "\1audioRoleChanged(self, role: QAudio.Role)", SIP_NULLPTR, SIP_NULLPTR},
    {"networkConfigurationChanged(QNetworkConfiguration)", "\1networkConfigurationChanged(self, configuration: QNetworkConfiguration)", SIP_NULLPTR, SIP_NULLPTR},
    {"playbackRateChanged(qreal)", "\1playbackRateChanged(self, rate: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"seekableChanged(bool)", "\1seekableChanged(self, seekable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferStatusChanged(int)", "\1bufferStatusChanged(self, percentFilled: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"videoAvailableChanged(bool)", "\1videoAvailableChanged(self, videoAvailable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioAvailableChanged(bool)", "\1audioAvailableChanged(self, available: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"mutedChanged(bool)", "\1mutedChanged(self, muted: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(int)", "\1volumeChanged(self, volume: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(qint64)", "\1positionChanged(self, position: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"durationChanged(qint64)", "\1durationChanged(self, duration: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaStatusChanged(QMediaPlayer::MediaStatus)", "\1mediaStatusChanged(self, status: QMediaPlayer.MediaStatus)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QMediaPlayer::State)", "\1stateChanged(self, newState: QMediaPlayer.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentMediaChanged(QMediaContent)", "\1currentMediaChanged(self, media: QMediaContent)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaChanged(QMediaContent)", "\1mediaChanged(self, media: QMediaContent)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QMediaPlayer::Error)", "\1error(self, error: QMediaPlayer.Error)", &methods_QMediaPlayer[8], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QMediaPlayer = {
    &::QMediaPlayer::staticMetaObject,
    0,
    signals_QMediaPlayer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlayer = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaPlayer,
        SIP_NULLPTR,
        &plugin_QMediaPlayer,
    },
    {
        sipNameNr_QMediaPlayer,
        {0, 0, 1},
        40, methods_QMediaPlayer,
        21, enummembers_QMediaPlayer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaPlayer,
    -1,
    -1,
    supers_QMediaPlayer,
    SIP_NULLPTR,
    init_type_QMediaPlayer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaPlayer,
    SIP_NULLPTR,
    array_QMediaPlayer,
    SIP_NULLPTR,
    release_QMediaPlayer,
    cast_QMediaPlayer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMediaPlayer,
    sizeof (::QMediaPlayer),
};
